/*
 *****************************************************
 *
 *  SaVi by Robert Thurman (thurman@geom.umn.edu) and
 *          Patrick Worfolk (worfolk@alum.mit.edu).
 *
 *  Copyright (c) 1997 by The Geometry Center.
 *  This file is part of SaVi.  SaVi is free software;
 *  you can redistribute it and/or modify it only under
 *  the terms given in the file COPYRIGHT which you should
 *  have received along with this file.  SaVi may be
 *  obtained by emailing savi@geom.umn.edu.
 *
 * Modified:
 *  10/8/97  Patrick Worfolk  Edited to add output
 *
 *****************************************************
 *  
 * savi.h
 *
 * headers for the different procs
 */

#ifndef _SAVI_H_
#define _SAVI_H_

#include "Satellite.h"
#include "stats_utils.h"

/* gv_init.c */
void gv_sat_create(Satellite, const Constellation *pconstellation);
void gv_trans_create(Satellite);
void gv_sat_list_create(const Constellation *pconstellation);
void gv_trans_list_create(Satellite_list);
int gv_init(void);

/* output.c */
char *output_on_cmd(int argc, char *argv[]);
char *output_off_cmd(int argc, char *argv[]);

/* earth.c */
char *earth_off_cmd(int argc, char *argv[]);
void earth_place(double t, const CentralBody *pcb);
char *earth_on_cmd(int argc, char *argv[]);
char *fancy_off_cmd(int argc, char *argv[]);
char *fancy_on_cmd(int argc, char *argv[]);
char *texture_on_cmd(int argc, char *argv[]);
char *texture_off_cmd(int argc, char *argv[]);
void earth_gv_delete(void);

/* sun.c */
char *sun_off_cmd(int argc, char *argv[]);
void sun_place(double t, const CentralBody *pcb);
char *sun_on_cmd(int argc, char *argv[]);
double sun_angle(Satellite s, const CentralBody *pcb);

/* plane.c */
extern char *plane_cmd(int argc, char *argv[]);
extern char *plane_off_cmd(int argc, char *argv[]);

/* satellites.c */
char *satellites_on_cmd(int argc, char *argv[]);
char *satellites_off_cmd(int argc, char *argv[]);
char *satellites_set_cmd(int argc, char *argv[]);
char *fancy_sat_on_cmd(int argc, char *argv[]);
char *fancy_sat_off_cmd(int argc, char *argv[]);
void satellite_display(Satellite s, const Constellation *pconstellation);
void satellites_relocate(const Constellation *pconstellation);
void satellite_delete(Satellite s);
void satellites_gv_delete(void);
void write_satellites_geom(const Constellation *pconstellation);

/* orbits.c */
char *orbits_on_cmd(int argc, char *argv[]);
char *orbits_off_cmd(int argc, char *argv[]);
char *orbits_set_cmd(int argc, char *argv[]);
void orbit_display(Satellite s, const Constellation *pconstellation);
void orbits_relocate(const Constellation *pconstellation);
void orbit_delete(Satellite s);
void orbits_gv_delete(void);
void write_orbits_geom(const Constellation *pconstellation);

/* cones.c */
char *cones_on_cmd(int argc, char *argv[]);
char *cones_off_cmd(int argc, char *argv[]);
char *cones_set_cmd(int argc, char *argv[]);
void cones_rebuild(void);
void cones_relocate(const Constellation *pconstellation);
void cone_display(Satellite, const Constellation *pconstellation);
void cone_delete(Satellite s);
void cones_gv_delete(void);
void write_cones_geom(const Constellation *pconstellation);

/* footprints.c */
char *footprints_on_cmd(int argc, char *argv[]);
char *footprints_off_cmd(int argc, char *argv[]);
char *footprints_set_cmd(int argc, char *argv[]);
void footprints_rebuild(void);
void footprints_relocate(const Constellation *pconstellation);
void footprint_display(Satellite s, const Constellation *pconstellation);
void footprint_delete(Satellite s);
void footprints_gv_delete(void);
void write_footprints_geom(const Constellation *pconstellation);

/* links.c */
char *links_on_cmd(int argc, char *argv[]);
char *links_off_cmd(int argc, char *argv[]);
char *links_set_cmd(int argc, char *argv[]);
void links_rebuild(void);
void links_relocate(const Constellation *pconstellation);
void link_display(Satellite s, const Constellation *pconstellation);
void link_delete(Satellite s);
void links_gv_delete(void);
void write_links_geom(const Constellation *pconstellation);
void links_output(FILE *fp, const Constellation *pconstellation);

/* time.c */
void time_update(const double);
void coverage_time_update(const double);
void coverage_init_time_update(const double);

/* coverage.c */
void coverage_compute(const Satellite_list sl, int, const CentralBody *pcb);
void coverage_display(const Satellite_list sl, int, const CentralBody *pcb);
char *coverage_on_cmd(int argc, char *argv[]);
char *coverage_off_cmd(int argc, char *argv[]);
int get_coverage_type(void);
void tracks_compute(const Satellite_list sl, const CentralBody *pcb);
char *tracks_on_cmd(int argc, char *argv[]);
char *tracks_off_cmd(int argc, char *argv[]);
char *project_tracks_on_cmd(int argc, char *argv[]);
char *project_tracks_off_cmd(int argc, char *argv[]);
void project_tracks_reset(void);
char *coverage2_on_cmd(int argc, char *argv[]);
char *coverage2_off_cmd(int argc, char *argv[]);
char *coverage_proj_cmd(int argc, char *argv[]);
char *coverage_angle_type_cmd(int argc, char *argv[]);
double mean_coverage(int projection, grid *g);
char *coverage_save_cmd(int argc, char *argv[]);

/* fisheye.c */
char *fisheye_on_cmd(int argc, char *argv[]);
char *fisheye_off_cmd(int argc, char *argv[]);
char *fisheye_vapors_on_cmd(int argc, char *argv[]);
char *fisheye_vapors_off_cmd(int argc, char *argv[]);
void fisheye_display(const Satellite_list sl, int force, const CentralBody *pcb);
char *fisheye_set_cmd(int argc, char *argv[]);

/* axes.c */
char *axes_on_cmd(int argc, char *argv[]);
char *axes_off_cmd(int argc, char *argv[]);

/* logo.c */
char *logo_on_cmd(int argc, char *argv[]);
char *logo_off_cmd(int argc, char *argv[]);

/* stars.c */
char *stars_on_cmd(int argc, char *argv[]);
char *stars_off_cmd(int argc, char *argv[]);

/* plan.c */
char *plan_nplanes_cmd(int argc, char *argv[]);
char *plan_plane_n_cmd(int argc, char *argv[]);
void plan_clear(Constellation *);
char *plan_dump_cmd(int argc, char *argv[]);
Satellite outofplane_neighbor(Satellite ps, int index);
Satellite inplane_neighbor(Satellite ps, int index);

typedef struct ViewModule {
  /* function called to extend geom to include new satellite
     or rewrite old satellite stuff; called by delayed_stuff */
  void (*write_geom_fn)(const Constellation *);

  /* function that must be called if the coverage angle/type is changed;
     called by coverage_angle_type_cmd */
  void (*coverage_rebuild_fn)(void);

  /* function used to display object when a
     new satellite is created; called by satellite_gv_create */
  void (*display_fn)(Satellite, const Constellation *);

  /* function used to relocate objects when the satellites have moved;
     called by satellite_gv_create */
  void (*relocate_fn)(const Constellation *);

  /* function to delete item associated to an individual satellite;
     called by sats_delete_cmd */
  void (*delete_fn)(Satellite);

  /* function called to turn options off; called by exit_cmd.
     These functions usually also call the corresponding gv_delete_fn. */
  char *(*off_cmd)(int, char *[]);
			
  /* function called to eliminate all trace of object in Geomview;
     called by sats_delete_all when all the satellites are deleted. */
  void (*gv_delete_fn)(void);

} ViewModule;

typedef struct CompModule {
  void (*update_fn)(const Constellation *);
} CompModule;


/*
 * These are used to provide unique identifiers for modules which
 * require certain information to be computed.  They are used like:
 *
 *          transforms_needed |= (1 << FOOTPRINTS);     <--- on
 *          transforms_needed &= ~(1 << FOOTPRINTS);    <--- off
 */
typedef enum {
  SATELLITES=0, CONES, FOOTPRINTS
} Module_Codes;

#endif
/* !_SAVI_H_ */
