#ifndef _UTILS_H_
#define _UTILS_H_

/*
 *****************************************************
 *
 *  SaVi by Robert Thurman (thurman@geom.umn.edu) and
 *          Patrick Worfolk (worfolk@alum.mit.edu).
 *
 *  Copyright (c) 1997 by The Geometry Center.
 *  This file is part of SaVi.  SaVi is free software;
 *  you can redistribute it and/or modify it only under
 *  the terms given in the file COPYRIGHT which you should
 *  have received along with this file.  SaVi may be
 *  obtained by emailing savi@geom.umn.edu.
 *
 *****************************************************
 *  
 * utils.h
 *
 */
#include <stdio.h>

/*
 * Define structs for Cartesian, Spherical and Horizon coordinates
 */

typedef struct CartesianCoordinates {
  double x, y, z;
} CartesianCoordinates;

typedef struct SphericalCoordinates {
  double r, theta, phi;
} SphericalCoordinates;

typedef struct HorizonCoordinates {
  double rho, az, el;
} HorizonCoordinates;

typedef struct LatLon {
  double lat, lon;
} LatLon;

int copyfile(FILE *, const char []);
void forward_over_comments(FILE *);
void identity(double [4][4]);
void error_format(const char[], const char[]);
void error_and_exit(const char[]);
void error(const char[]);

double norm(CartesianCoordinates *px);
void normalize(CartesianCoordinates *px);
double dot(CartesianCoordinates *px, CartesianCoordinates *py);
void cross_product(CartesianCoordinates *pucv, CartesianCoordinates *pu,
		   CartesianCoordinates *pv);
void linear_com(double a, CartesianCoordinates *u,  
		double b, CartesianCoordinates *v, CartesianCoordinates *w);
double distance(CartesianCoordinates *u, CartesianCoordinates *v);
void print_vec(const char msg[], CartesianCoordinates *pv);
void rotate_z(CartesianCoordinates *v_old, const double theta,
	  CartesianCoordinates *v_new);

void millisleep(int ms);
char *get_the_time(void);
char *get_user_info(void);

#endif /* !_UTILS_H_ */
