/*
 *****************************************************
 *
 *  SaVi by Robert Thurman (thurman@geom.umn.edu) and
 *          Patrick Worfolk (worfolk@geom.umn.edu).
 *
 *  Copyright (c) 1995-1996 by The Geometry Center.
 *  All rights reserved.
 *
 *****************************************************
 *  
 * output.c
 *
 * code for writing output to file
 */
#include <stdio.h>
#include <stdlib.h>

#include "globals.h"
#include "constants.h"
#include "savi.h"

int output_on = FALSE; /* flag for output existing */
FILE *output_fp = NULL;

static needs_closing = FALSE;

static void output_write_info(FILE *fp);

char *
output_on_cmd(int argc, char *argv[])
{

  if (argc < 3) {
    /* no filename specified, so use stderr */
    output_fp = stderr;

  } else {

    /* open file in append mode if it exists */
    output_fp = fopen(argv[2], "a");

    if (output_fp == (FILE *) NULL) {

      /* unsuccesful at opening file, use stderr */
      output_fp = stderr;

    } else {

      /* successful opening file, so we'll need to close it later */
      needs_closing = TRUE;

    }

  }

  output_on = TRUE;
  output_write_info(output_fp);

  return EMPTY_str;
}

char *
output_off_cmd(int argc, char *argv[])
{
  if ( needs_closing == TRUE ) {
    fclose(output_fp);
    needs_closing = FALSE;
  }

  output_fp = NULL;
  output_on = FALSE;

  return EMPTY_str;
}


static void
output_write_info(FILE *fp)
{
  char *vp = Version;

  fprintf(fp, "#\n# ");
  while ( (*vp != '\n') && fputc(*(vp++), fp));
  fprintf(fp, "\n# %s\n# %s\n#\n", get_user_info(), get_the_time());
}
