#
######################################################
#
#  SaVi by Robert Thurman (thurman@geom.umn.edu) and
#          Patrick Worfolk (worfolk@alum.mit.edu).
#
#  Copyright (c) 1997 by The Geometry Center.
#  This file is part of SaVi.  SaVi is free software;
#  you can redistribute it and/or modify it only under
#  the terms given in the file COPYRIGHT which you should
#  have received along with this file.  SaVi may be
#  obtained by emailing savi@geom.umn.edu.
#
######################################################
#  
# coverage.tcl
#

#
# define the size of the image
#

#
# Note: IM_W and IM_H and linked to C variables for the image size
#

set im_x_offset 2
set im_y_offset 2

proc coverage(build) {} {
    global coverage_flag coverage_rect_flag coverage_angle_flag IM_W IM_H \
	im_x_offset im_y_offset coverage2_flag \
	tracks_flag project_tracks_flag FONT COLOR
	

    if [winfo exists .coverage] {
	wm deiconify .coverage
	raise .coverage
	coverage(update)
	return
    }

    set name [build_Toplevel coverage]

    build_Title $name "Coverage statistics"

    set cmd [build_CmdFrame $name cmd]

    set c "$cmd.c"
    canvas $c -bg black -width $IM_W -height $IM_H
    pack $c
    set im [image create photo im_coverage -width $IM_W -height $IM_H]
    $c create image [expr $IM_W/2+$im_x_offset] [expr $IM_H/2+$im_y_offset] \
	-image $im

#    set p "$cmd.p"
#    plot $p -bg black -width $IM_W -height $IM_H
#    pack $p

    # catch button click in map to get Lat/Long
    bind $c <Button-1> {coverage(lat_long) %x %y}

    set cmda [build_StdFrame $cmd a]
    build_Optionslist $cmda olist \
	{"Show coverage" coverage_flag} \
	{"Show ground tracks" tracks_flag} 
#	{"Project ground tracks for the next..." project_tracks_flag}
    pack $cmda.olist -side left

    # the background colors should match the colors in coverage_vis.c
    build_StdFrame $cmda cf
    label $cmda.cf.0 -text "Coverage color coding:" -font $FONT(label) -bg $COLOR(bg)
    label $cmda.cf.1 -text 1 -font $FONT(fixed) -bg #ffff00
    label $cmda.cf.2 -text 2 -font $FONT(fixed) -bg #ff7f00
    label $cmda.cf.3 -text 3 -font $FONT(fixed) -bg #ff2f00
    label $cmda.cf.4 -text "4+" -font $FONT(fixed) -bg #ff0000
    pack $cmda.cf.0 $cmda.cf.1 $cmda.cf.2 $cmda.cf.3 $cmda.cf.4 -expand 1 -fill x -side left -ipadx 2m -ipady 2m -padx 1m -pady 1m
    pack $cmda.cf -side right

    pack $cmda -fill x -expand 1

    build_LabelEntryColumns $cmd le2 \
	{lcheckbox "" project_tracks_flag} \
	{ientry "" {tracks_interval}} \
	{text "" {hours}} 

#    build_Optionslist $cmd olist2 \
#	{"Show coverage 2" coverage2_flag}

    build_IPopupMenu $cmd p0 "Projection:" \
	coverage_rect_flag coverage(foot) {"Sinusoidal" "Cylindrical"}

    build_IPopupMenu $cmd p1 "Footprint is computed by:" \
	coverage_angle_flag coverage(foot) {"Mask elevation" "Satellite cone"}
	
    build_LabelEntryColumns $cmd le1 \
	{text "" {Angle}} \
	      {ientry "" {coverage_angle}}

    build_LabelEntryColumns $cmd le0 \
	{label "" {coverage_init_time coverage_time coverage mean_coverage}}

    pack $cmd -fill x

    build_DismissButtonbar $name dbbar coverage(dismiss)

    update
    coverage(update)
}

proc coverage(dismiss) {} {
    global coverage_flag

    set coverage_flag 0
    destroy .coverage
}

proc coverage(update) {} {
    global coverage_flag

    if {![winfo exists .coverage]} return
    set flag $coverage_flag
    set coverage_flag 1
    if {$flag == 0} {
	set coverage_flag 0
    }
}

proc coverage(lat_long) {x y} {
    global Fisheye coverage_rect_flag IM_W IM_H im_x_offset im_y_offset

    set x [expr $x-$im_x_offset]
    set y [expr $y-$im_y_offset]

    set HALF_X [expr $IM_W/2]
    set HALF_Y [expr $IM_H/2]

    if {$coverage_rect_flag == 0} {
	set lat [expr ($HALF_Y-$y)/double($HALF_Y)*90.0]
	if {abs($lat) == 90} {
	    set long 0
	} else {
	    set long [expr ($x-$HALF_X)/double($HALF_X)/cos($lat/180.0*3.14159)*180.0-90.0]
	}
	if {$long > 90} {
	    set long 90
	} elseif {$long < -270} {
	    set long -270
	}
    } else {
	set long [expr ($x-$HALF_X)/double($IM_W)*360.0-90.0]
	set y [expr 1-$y/double($IM_H)*2]
	if {$y < -1} {
	    set y -1
	}
	set lat [expr asin($y)/3.1416*180.0]
    }

    if {$long <= -180} {
	set long [expr $long+360.0]
    }

    set Fisheye(lat_degrees) [expr {$lat<0 ? -int(-$lat) : int($lat)} ]
    set Fisheye(lat_minutes) [expr abs($lat-$Fisheye(lat_degrees))*60.0]
    set Fisheye(long_degrees) [expr {$long<0 ? -int(-$long) : int($long)} ]
    set Fisheye(long_minutes) [expr abs($long-$Fisheye(long_degrees))*60.0]
    fisheye(apply)

}

proc coverage(foot) {} {
    global project_tracks_flag

    set project_tracks_flag 0
}










