#
######################################################
#
#  SaVi by Robert Thurman (thurman@geom.umn.edu) and
#          Patrick Worfolk (worfolk@alum.mit.edu).
#
#  Copyright (c) 1997 by The Geometry Center.
#  This file is part of SaVi.  SaVi is free software;
#  you can redistribute it and/or modify it only under
#  the terms given in the file COPYRIGHT which you should
#  have received along with this file.  SaVi may be
#  obtained by emailing savi@geom.umn.edu.
#
######################################################
#  
# init.tcl
#

proc app_init {} {
    global COLOR FONT TITLE Load Save env geomview_module output
    global axes_flag orbits_flag plane_flag satellites_flag sun_flag \
        fancy_sat_flag earth_flag fancy_earth_flag texture_flag \
	stars_flag coverage_flag coverage_rect_flag cones_flag \
	footprints_flag coverage_angle_flag geomview_flag \
	fisheye_flag fisheye_vapors_flag oe Fisheye \
        tracks_flag project_tracks_flag realtime_flag
#	coverage2_flag \

    # set colors for windows
    set COLOR(bg) #acf
    set COLOR(abg) #57f
    set COLOR(entry) white
    set FONT(button) -Adobe-Helvetica-Medium-R-Normal--*-120-*
    set FONT(label) -Adobe-Helvetica-Medium-R-Normal--*-120-*
    set FONT(fixed) -Adobe-Courier-Medium-R-Normal--*-120-*
#    set FONT(fixed) -Misc-Fixed-Medium-R-Normal--*-120-*

    # close the default toplevel window
    wm withdraw .

    # set up string for title bar
    set TITLE "SaVi"

    # build top window
    main(build)

    # setup traces for option variables
    trace variable axes_flag w flag_change
    trace variable orbits_flag w flag_change
    trace variable cones_flag w flag_change
    trace variable footprints_flag w flag_change
    trace variable plane_flag w flag_change
    trace variable satellites_flag w flag_change
    trace variable fancy_sat_flag w flag_change
    trace variable fancy_earth_flag w flag_change
    trace variable earth_flag w flag_change
    trace variable texture_flag w flag_change
    trace variable sun_flag w flag_change
    trace variable stars_flag w flag_change
    trace variable geomview_flag w flag_change
    trace variable coverage_flag w flag_change
    trace variable tracks_flag w flag_change
    trace variable project_tracks_flag w flag_change
#    trace variable coverage2_flag w flag_change
    trace variable coverage_rect_flag w flag_change
    trace variable coverage_angle_flag w flag_change
    trace variable fisheye_flag w flag_change
    trace variable fisheye_vapors_flag w flag_change
    trace variable realtime_flag w flag_change

    # initialize load directory
    if {[info exists env(OLDCWD)]} {
	set Load(directory) $env(OLDCWD)
    }
    set Load(filename) ""

    # initialize save directory
    if {[info exists env(OLDCWD)]} {
	set Save(directory) $env(OLDCWD)
    }
    set Save(filename) ""

    # initialize output directory
    if {[info exists env(OLDCWD)]} {
	set output(directory) $env(OLDCWD)
    }
    set output(filename) ""

    # initialize the display
    update

    if {$geomview_module == 1} {
	set geomview_flag 1

	set axes_flag 1

	set fancy_earth_flag 0
	set earth_flag 1

	set fancy_sat_flag 0
	set satellites_flag 1

	set orbits_flag 1

	set cones_flag 0

	set footprints_flag 0
    }

    set plane_flag 0
    set realtime_flag 0
    set coverage_flag 0
    set tracks__flag 0
    set project_tracks__flag 0
#    set coverage2_flag 0
    set coverage_rect_flag 0
    set coverage_angle_flag 0

    set Fisheye(lat_degrees) 44
    set Fisheye(lat_minutes) 58.529
    set Fisheye(long_degrees) -93
    set Fisheye(long_minutes) 16.612
    fisheye(apply)
}

proc flag_change {name element op} {
    upvar #0 $name flag

    if {$name == "axes_flag"} {
	if {$flag == 1} {satellites AXES_ON} else {satellites AXES_OFF}
    } elseif {$name == "satellites_flag"} {
	if {$flag == 1} {satellites SATELLITES_ON} else {satellites SATELLITES_OFF}
    } elseif {$name == "fancy_sat_flag"} {
	if {$flag == 1} {satellites FANCY_SAT_ON} else {satellites FANCY_SAT_OFF}
    } elseif {$name == "orbits_flag"} {
	if {$flag == 1} {satellites ORBITS_ON} else {satellites ORBITS_OFF}
    } elseif {$name == "cones_flag"} {
	if {$flag == 1} {satellites CONES_ON} else {satellites CONES_OFF}
    } elseif {$name == "footprints_flag"} {
	if {$flag == 1} {satellites FOOTPRINTS_ON} else {satellites FOOTPRINTS_OFF}
    } elseif {$name == "earth_flag"} {
	if {$flag == 1} {satellites EARTH_ON} else {satellites EARTH_OFF}
    } elseif {$name == "fancy_earth_flag"} {
	if {$flag == 1} {satellites FANCY_EARTH_ON} else {satellites FANCY_EARTH_OFF}
    } elseif {$name == "texture_flag"} {
	if {$flag == 1} {satellites TEXTURE_ON} else {satellites TEXTURE_OFF}
    } elseif {$name == "sun_flag"} {
	if {$flag == 1} {satellites SUN_ON} else {satellites SUN_OFF}
    } elseif {$name == "stars_flag"} {
	if {$flag == 1} {satellites STARS_ON} else {satellites STARS_OFF}
    } elseif {$name == "realtime_flag"} {
	if {$flag == 1} {satellites REALTIME_ON} else {satellites REALTIME_OFF}
    } elseif {$name == "plane_flag"} {
	if {$flag == 1} {satellites PLANE 0.0 0.0} else {satellites PLANE_OFF}
    } elseif {$name == "geomview_flag"} {
	if {$flag == 1} {satellites GEOMVIEW_ON} else {satellites GEOMVIEW_OFF}
    } elseif {$name == "coverage_flag"} {
	if {$flag == 1} {satellites COVERAGE_ON} else {satellites COVERAGE_OFF}
    } elseif {$name == "tracks_flag"} {
	if {$flag == 1} {satellites TRACKS_ON} else {satellites TRACKS_OFF}
    } elseif {$name == "project_tracks_flag"} {
	if {$flag == 1} {satellites PROJECT_TRACKS_ON} else {satellites PROJECT_TRACKS_OFF}
    } elseif {$name == "coverage2_flag"} {
	if {$flag == 1} {satellites COVERAGE2_ON} else {satellites COVERAGE2_OFF}
    } elseif {$name == "coverage_rect_flag"} {
	if {$flag == 1} {satellites COVERAGE_PROJ 1} else {satellites COVERAGE_PROJ 0}
    } elseif {$name == "coverage_angle_flag"} {
	if {$flag == 1} {satellites COVERAGE_ANGLE_TYPE 1} else {satellites COVERAGE_ANGLE_TYPE 0}
    } elseif {$name == "fisheye_flag"} {
	if {$flag == 1} {satellites FISHEYE_ON} else {satellites FISHEYE_OFF}
    } elseif {$name == "fisheye_vapors_flag"} {
	if {$flag == 1} {satellites FISHEYE_VAPORS_ON} else {satellites FISHEYE_VAPORS_OFF}
    } else {
	puts "Unrecognized flag: $name"
    }
}






