#
######################################################
#
#  SaVi by Robert Thurman (thurman@geom.umn.edu) and
#          Patrick Worfolk (worfolk@alum.mit.edu).
#
#  Copyright (c) 1997 by The Geometry Center.
#  This file is part of SaVi.  SaVi is free software;
#  you can redistribute it and/or modify it only under
#  the terms given in the file COPYRIGHT which you should
#  have received along with this file.  SaVi may be
#  obtained by emailing savi@geom.umn.edu.
#
######################################################
#  
# main.tcl 
#

proc main(build) {} {
    global COLOR FONT TITLE geomview_module

    set name [build_Toplevel main]

    wm title $name "$TITLE"

    build_Menubar $name mbar \
	{"Help"} \
	{"File" \
	     {"Load..." "load(build)"} \
	     {"Save..." "save(build)"} \
	     {"Output..." output(build)} \
	     {"About..." "about(build)"} \
	     {} \
	     {"Exit" "main(exit)"} } \
	{"Options" \
	     {} } \
	{"Panels" \
	     {"Coverage..." coverage(build)} \
	     {"Fisheye..." fisheye(build)} \
	     {"Parameters..." params(build)} \
	     {"Intersatellite links..." links(build)} } \
	{"Constellations" \
	     {"Iridium" "main(constellation) iridium"} \
	     {"Celestri" "main(constellation) celestri"} \
	     {"Globalstar" "main(constellation) globalstar"} \
	     {"Teledesic (288)" "main(constellation) teledesic_288"} \
	     {"Teledesic (840)" "main(constellation) teledesic_840"} \
	     {"ICO" "main(constellation) ico"} \
	     {"Millimeter" "main(constellation) mm"} \
	     {"Aries" "main(constellation) aries"} \
	     {"Ellipso" "main(constellation) ellipso"} \
	     {"NUONCE" "main(constellation) nuonce"} \
	     {"GPS" "main(constellation) gps"} \
	     {"Skybridge" "main(constellation) skybridge"} \
	     {"Odyssey" "main(constellation) odyssey"} \
	     {"LEq0" "main(constellation) leq0"} \
	     {} \
	     {"Delete current" "main(delete_all)"} }

# Uncomment and add this line anywhere in the above list.
#	     {"Teledesic" "main(constellation) teledesic"} \
#
    
    if {$geomview_module == 1} {
	build_options_menu $name.mbar.b1 \
	    {"Show satellites" satellites_flag} \
	    {"Use detailed satellite" fancy_sat_flag} \
	    {} \
	    {"Show satellite orbits" orbits_flag} \
	    {"Show coverage cones" cones_flag} \
	    {"Show footprints" footprints_flag} \
	    {} \
	    {"Show central body" earth_flag} \
	    {"Use detailed earth model" fancy_earth_flag} \
	    {"Texture mapping available" texture_flag} \
	    {} \
	    {"Show geocentric-equatorial coordinate axes" axes_flag} \
	    {"Show plane of orbit" plane_flag} \
	    {"Show star field" stars_flag} \
	    {"Use sun lighting" sun_flag} \
	    {} \
	    {"Real-time mode" realtime_flag} \
	    {"Animate in geomview" geomview_flag}
	} else {
	    build_options_menu $name.mbar.b1 \
		{"Real-time mode" realtime_flag}
	}
    

    set cmd [build_CmdFrame $name cmd]

    build_LabelEntryColumns $cmd le0 \
	{label "" {time}}

    build_LabelEntryColumns $cmd le1 \
	{text "" {"Time step (secs) or factor:"} } \
	  {dentry "" {delta_t} }


    label $cmd.l -text "semi-major axis     eccentricity       inclination     long.asc.node     arg.periap.      time.periap." \
	-font $FONT(label) -bg $COLOR(bg)
    listbox $cmd.lb -yscrollcommand "$cmd.scroll set" \
	-height 10 -width 66 -selectmode single \
	-font $FONT(fixed) -bg $COLOR(entry) -selectbackground $COLOR(abg)
    pack $cmd.l -side top -anchor w
    pack $cmd.lb -side left
    bind $cmd.lb <Button-1> {main(select) [%W nearest %y]}
    bind $cmd.lb <Double-Button-1> {main(dblselect) [%W nearest %y]}
    scrollbar $cmd.scroll -command "$cmd.lb yview" -bg $COLOR(bg)
    pack $cmd.scroll -side right -fill y

    pack $cmd -fill both -expand 1

    build_Buttonbar $name bb0 \
	{"New" main(new) } \
	{"Copy" main(copy) } \
	{"Delete" main(delete) } \
	{"Unselect" main(unselect) }


    build_Buttonbar $name bb1 \
	{"Reset" {satellites RESET}} \
	{"< step" {satellites BACK_STEP}} \
	{"<<<<<<" main(backwards)} \
	{"STOP" main(stop)} \
	{">>>>>>" main(forwards)} \
	{"step >" {satellites FORW_STEP}}

}

proc main(forwards) {} {
    global COLOR

    if {"OK" == [satellites FORWARDS]} {
	.main.bb1.b4 configure -bg $COLOR(abg)
    }
}

proc main(backwards) {} {
    global COLOR

    if {"OK" == [satellites BACKWARDS]} {
	.main.bb1.b2 configure -bg $COLOR(abg)
    }
}

proc main(stop) {} {
    global COLOR

    set ok [satellites STOP]
    if {"OK" == $ok} {
	.main.bb1.b2 configure -bg $COLOR(bg)
	.main.bb1.b4 configure -bg $COLOR(bg)
    }
}

proc main(exit) {} {
    satellites EXIT
    exit
}

proc main(update) {} {
    set i 0
    set n [.main.cmd.lb size]
    set noe [satellites GET $i]
    while {$noe != ""} {
	.main.cmd.lb insert $i [string range $noe 0 64]
	incr i
	set noe [satellites GET $i]
    }
    if {$n > 0} {
	.main.cmd.lb delete $i [expr $i+$n-1]
    }

    edit(update)
}

proc main(update_one) n {
    set noe [satellites GET $n]
    .main.cmd.lb insert $n [string range $noe 0 64]
    .main.cmd.lb select set $n
    incr n
    .main.cmd.lb delete $n
}

proc main(select) {n} {
    if {[llength $n] > 0} {
        .main.cmd.lb select set $n
	edit(set) [lindex $n 0]
	satellites TAG [lindex $n 0]
    }
    return
}

proc main(dblselect) {n} {
    edit(build)
    main(select) $n
}

proc main(new) {} {
    set nn [satellites NEW]
    main(update)
    main(select) [list $nn]
}

proc main(copy) {} {
    set n [.main.cmd.lb curselection]
    if {[llength $n] > 0} {
	set nn [satellites COPY [lindex $n 0]]
	main(update)
	main(select) [list $nn]
    }
}

proc main(delete) {} {
    set n [.main.cmd.lb curselection]
    if {[llength $n] > 0} {
	satellites DELETE [lindex $n 0]
	main(update)
	coverage(update)
	fisheye(update)
    }
}

proc main(unselect) {} {
    set n [.main.cmd.lb curselection]
    if {[llength $n] > 0} {
	satellites UNTAG [lindex $n 0]
	main(update)
    }
}

proc main(delete_all) {} {
    global project_tracks_flag

    set project_tracks_flag 0
    satellites DELETE_ALL
    main(update)
    coverage(update)
    fisheye(update)
}

proc main(iridium) {} {
    satellites DELETE_ALL
    satellites IRIDIUM
    main(update)
    coverage(update)
    fisheye(update)
}

proc main(constellation) {filename} {
    satellites DELETE_ALL
    satellites GV_SEND "(ui-freeze on)"
    source data/$filename
    satellites GV_SEND "(ui-freeze off)"
    main(update)
    coverage(update)
    fisheye(update)
}
