#
######################################################
#
#  SaVi by Robert Thurman (thurman@geom.umn.edu) and
#          Patrick Worfolk (worfolk@alum.mit.edu).
#
#  Copyright (c) 1997 by The Geometry Center.
#  This file is part of SaVi.  SaVi is free software;
#  you can redistribute it and/or modify it only under
#  the terms given in the file COPYRIGHT which you should
#  have received along with this file.  SaVi may be
#  obtained by emailing savi@geom.umn.edu.
#
######################################################
#  
# params.tcl
#


proc params(build) {} {
    
    if [winfo exists .params] {
	wm deinconfiy .params
	raise .params
	return
    }

    set name [build_Toplevel params]
    build_Title $name Parameters

    set cmd [build_CmdFrame $name cmd]

    build_LabelEntryColumns $cmd le0 \
	{text " " {"Radius (km)" "Mu (km^3/s^2)" "Rotation rate (rad/s)" \
		   "Oblateness (J2)" "Orbital period (s)" "Tilt (deg)"} } \
	{dentry "Central body" {tparams(Radius) tparams(Mu) tparams(Omega) \
				tparams(J2) tparams(orbital_period) \
			        tparams(tilt) } }

    pack $cmd -fill both -expand 1

    build_DismissButtonbar $name dbbar "destroy .params" \
	{"Apply" params(apply)} \
	{"Cancel" params(cancel)} \
	{"Reset to default" params(reset)}

    update
    params(cancel)
}

proc params(apply) {} {
    global params tparams

    set inds [array names tparams]
    foreach ind $inds {
	set params($ind) $tparams($ind)
    }
    
    # now update other panels if necessary
    edit(update)
}

proc params(cancel) {} {
    global params tparams

    set inds [array names tparams]
    foreach ind $inds {
	set tparams($ind) $params($ind)
    }
}

proc params(reset) {} {
    satellites RESET_PARAMS
    params(cancel)
}
